@@ -37,9 +37,21 @@ class BlacklistTokenSerializer(serializers.ModelSerializer):
         iat = payload.get('iat', unix_epoch())
         expires_at_unix_time = iat + api_settings.JWT_EXPIRATION_DELTA.total_seconds()
 
+        # For refreshed tokens, record the token id of the original token.
+        # This allows us to invalidate the whole family of tokens from
+        # the same original authentication event.
+        token_id = payload.get('orig_jti') or payload.get('jti')
+
         self.validated_data.update({
+            'token_id': token_id,
             'user': check_user(payload),
             'expires_at':
                 make_aware(datetime.utcfromtimestamp(expires_at_unix_time)),
         })
+
+        # Don't store the token if we can rely on token IDs.
+        # The token values are still sensitive until they expire.
+        if api_settings.JWT_TOKEN_ID == 'require':
+            del self.validated_data['token']
+
         return super(BlacklistTokenSerializer, self).save(**kwargs)
