@@ -2,7 +2,11 @@
 
 from __future__ import unicode_literals
 
-from django.utils.translation import ugettext_lazy as _
+
+try:
+    from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    from django.utils.translation import gettext_lazy as _
 
 from rest_framework import status
 from rest_framework.reverse import reverse
